#!/usr/bin/env python

"""
A Web interface to the user profile.

Copyright (C) 2015 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from imiptools import config
from imipweb.resource import ResourceClient

class ProfilePage(ResourceClient):

    "A request handler for the user profile page."

    # See: imiptools.profile

    pref_labels = {
        "CN"                    : "Common name",
        "LANG"                  : "Language",
        "TZID"                  : "Time zone/regime",
        "add_method_response"   : "Respond to messages adding events with...",
        "event_refreshing"      : "Handle event refresh requests automatically",
        "freebusy_bundling"     : "Bundle free/busy details with messages",
        "freebusy_messages"     : "Notify about received free/busy messages",
        "freebusy_offers"       : "Reserve time periods when making counter-proposals",
        "freebusy_publishing"   : "Publish free/busy details via the Web",
        "freebusy_sharing"      : "Share free/busy information at all",
        "incoming"              : "Incoming calendar messages presented using...",
        "organiser_replacement" : "Recognise which kinds of participants as replacement organisers...",
        "participating"         : "Participate in the calendar system at all?",
        "permitted_times"       : None,
        }

    def handle_request(self):
        args = self.env.get_args()
        save = args.has_key("save")
        cancel = args.has_key("cancel")
        action = save or cancel

        if not action:
            return ["action"]

        return None

    # Output fragment methods.

    def show_preferences(self, errors=None):
        page = self.page

        # Show the range of preferences, getting all possible entries and using
        # configuration defaults.

        prefs = self.get_preferences()
        items = prefs.items(True, None, True)
        items.sort()

        page.table(class_="profile", cellspacing=5, cellpadding=5)
        page.thead()
        page.tr()
        page.th("Preferences", class_="mainheading", colspan=2)
        page.tr.close()
        page.thead.close()
        page.tbody()

        for name, value in items:
            label = self.pref_labels.get(name)
            if not label:
                continue

            page.tr()
            page.th(class_="profileheading %s%s" % (name, errors and name in errors and " error" or ""))
            page.label(label)
            page.th.close()
            page.td()
            page.input(name=name, value=(value or ""), type="text", class_="preference")
            page.td.close()
            page.tr.close()

        page.tbody.close()
        page.table.close()

    # Full page output methods.

    def show(self):

        "Show the preferences of a user."

        errors = self.handle_request()

        if not errors:
            return True

        self.new_page(title="Profile")
        self.show_preferences(errors)

        return True

# vim: tabstop=4 expandtab shiftwidth=4
